# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class KmsManagementClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.key_management.KmsManagementClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new KmsManagementClientCompositeOperations object

        :param KmsManagementClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def backup_key_and_wait_for_state(self, key_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.backup_key` and waits for the :py:class:`~oci.key_management.models.Key` acted upon
        to enter the given state(s).

        :param str key_id: (required)
            The OCID of the key.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.Key.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.backup_key`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.backup_key(key_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def cancel_key_deletion_and_wait_for_state(self, key_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.cancel_key_deletion` and waits for the :py:class:`~oci.key_management.models.Key` acted upon
        to enter the given state(s).

        :param str key_id: (required)
            The OCID of the key.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.Key.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.cancel_key_deletion`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.cancel_key_deletion(key_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def cancel_key_version_deletion_and_wait_for_state(self, key_id, key_version_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.cancel_key_version_deletion` and waits for the :py:class:`~oci.key_management.models.KeyVersion` acted upon
        to enter the given state(s).

        :param str key_id: (required)
            The OCID of the key.

        :param str key_version_id: (required)
            The OCID of the key version.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.KeyVersion.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.cancel_key_version_deletion`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.cancel_key_version_deletion(key_id, key_version_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key_version(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_key_and_wait_for_state(self, create_key_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.create_key` and waits for the :py:class:`~oci.key_management.models.Key` acted upon
        to enter the given state(s).

        :param oci.key_management.models.CreateKeyDetails create_key_details: (required)
            CreateKeyDetails

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.Key.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.create_key`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_key(create_key_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_key_version_and_wait_for_state(self, key_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.create_key_version` and waits for the :py:class:`~oci.key_management.models.KeyVersion` acted upon
        to enter the given state(s).

        :param str key_id: (required)
            The OCID of the key.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.KeyVersion.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.create_key_version`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_key_version(key_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key_version(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def disable_key_and_wait_for_state(self, key_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.disable_key` and waits for the :py:class:`~oci.key_management.models.Key` acted upon
        to enter the given state(s).

        :param str key_id: (required)
            The OCID of the key.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.Key.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.disable_key`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.disable_key(key_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def enable_key_and_wait_for_state(self, key_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.enable_key` and waits for the :py:class:`~oci.key_management.models.Key` acted upon
        to enter the given state(s).

        :param str key_id: (required)
            The OCID of the key.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.Key.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.enable_key`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.enable_key(key_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def schedule_key_deletion_and_wait_for_state(self, key_id, schedule_key_deletion_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.schedule_key_deletion` and waits for the :py:class:`~oci.key_management.models.Key` acted upon
        to enter the given state(s).

        :param str key_id: (required)
            The OCID of the key.

        :param oci.key_management.models.ScheduleKeyDeletionDetails schedule_key_deletion_details: (required)
            ScheduleKeyDeletionDetails

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.Key.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.schedule_key_deletion`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.schedule_key_deletion(key_id, schedule_key_deletion_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def schedule_key_version_deletion_and_wait_for_state(self, key_id, key_version_id, schedule_key_version_deletion_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.schedule_key_version_deletion` and waits for the :py:class:`~oci.key_management.models.KeyVersion` acted upon
        to enter the given state(s).

        :param str key_id: (required)
            The OCID of the key.

        :param str key_version_id: (required)
            The OCID of the key version.

        :param oci.key_management.models.ScheduleKeyVersionDeletionDetails schedule_key_version_deletion_details: (required)
            ScheduleKeyVersionDeletionDetails

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.KeyVersion.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.schedule_key_version_deletion`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.schedule_key_version_deletion(key_id, key_version_id, schedule_key_version_deletion_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key_version(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_key_and_wait_for_state(self, key_id, update_key_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.key_management.KmsManagementClient.update_key` and waits for the :py:class:`~oci.key_management.models.Key` acted upon
        to enter the given state(s).

        :param str key_id: (required)
            The OCID of the key.

        :param oci.key_management.models.UpdateKeyDetails update_key_details: (required)
            UpdateKeyDetails

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.key_management.models.Key.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.key_management.KmsManagementClient.update_key`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_key(key_id, update_key_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_key(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import announcements_service_type_mapping
missing = Sentinel("Missing")


class AnnouncementClient(object):
    """
    Manage Oracle Cloud Infrastructure console announcements.
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20180904',
            'service_endpoint_template': 'https://announcements.{region}.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        self.base_client = BaseClient("announcement", config, signer, announcements_service_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')

    def get_announcement(self, announcement_id, **kwargs):
        """
        Gets the details of a specific announcement.


        :param str announcement_id: (required)
            The OCID of the announcement.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.announcements_service.models.Announcement`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/announcementsservice/get_announcement.py.html>`__ to see an example of how to use get_announcement API.
        """
        resource_path = "/announcements/{announcementId}"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_announcement got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementId": announcement_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="Announcement")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="Announcement")

    def get_announcement_user_status(self, announcement_id, **kwargs):
        """
        Gets information about whether a specific announcement was acknowledged by a user.


        :param str announcement_id: (required)
            The OCID of the announcement.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.announcements_service.models.AnnouncementUserStatusDetails`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/announcementsservice/get_announcement_user_status.py.html>`__ to see an example of how to use get_announcement_user_status API.
        """
        resource_path = "/announcements/{announcementId}/userStatus"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_announcement_user_status got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementId": announcement_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="AnnouncementUserStatusDetails")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="AnnouncementUserStatusDetails")

    def list_announcements(self, compartment_id, **kwargs):
        """
        Gets a list of announcements for the current tenancy.


        :param str compartment_id: (required)
            The OCID of the compartment. Because announcements are specific to a tenancy, this is the
            OCID of the root compartment.

        :param int limit: (optional)
            The maximum number of items to return in a paginated \"List\" call.

        :param str page: (optional)
            The value of the `opc-next-page` response header from the previous \"List\" call.

        :param str announcement_type: (optional)
            The type of announcement.

        :param str lifecycle_state: (optional)
            The announcement's current lifecycle state.

            Allowed values are: "ACTIVE", "INACTIVE"

        :param bool is_banner: (optional)
            Whether the announcement is displayed as a console banner.

        :param str sort_by: (optional)
            The criteria to sort by. You can specify only one sort order.

            Allowed values are: "timeOneValue", "timeTwoValue", "timeCreated", "referenceTicketNumber", "summary", "announcementType"

        :param str sort_order: (optional)
            The sort order to use. (Sorting by `announcementType` orders the announcements list according to importance.)

            Allowed values are: "ASC", "DESC"

        :param datetime time_one_earliest_time: (optional)
            The boundary for the earliest `timeOneValue` date on announcements that you want to see.

        :param datetime time_one_latest_time: (optional)
            The boundary for the latest `timeOneValue` date on announcements that you want to see.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.announcements_service.models.AnnouncementsCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/announcementsservice/list_announcements.py.html>`__ to see an example of how to use list_announcements API.
        """
        resource_path = "/announcements"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "limit",
            "page",
            "announcement_type",
            "lifecycle_state",
            "is_banner",
            "sort_by",
            "sort_order",
            "time_one_earliest_time",
            "time_one_latest_time",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_announcements got unknown kwargs: {!r}".format(extra_kwargs))

        if 'lifecycle_state' in kwargs:
            lifecycle_state_allowed_values = ["ACTIVE", "INACTIVE"]
            if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                raise ValueError(
                    "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeOneValue", "timeTwoValue", "timeCreated", "referenceTicketNumber", "summary", "announcementType"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        query_params = {
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "compartmentId": compartment_id,
            "announcementType": kwargs.get("announcement_type", missing),
            "lifecycleState": kwargs.get("lifecycle_state", missing),
            "isBanner": kwargs.get("is_banner", missing),
            "sortBy": kwargs.get("sort_by", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "timeOneEarliestTime": kwargs.get("time_one_earliest_time", missing),
            "timeOneLatestTime": kwargs.get("time_one_latest_time", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="AnnouncementsCollection")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="AnnouncementsCollection")

    def update_announcement_user_status(self, announcement_id, status_details, **kwargs):
        """
        Updates the status of the specified announcement with regard to whether it has been marked as read.


        :param str announcement_id: (required)
            The OCID of the announcement.

        :param oci.announcements_service.models.AnnouncementUserStatusDetails status_details: (required)
            The information to use to update the announcement's read status.

        :param str if_match: (optional)
            The locking version, used for optimistic concurrency control.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.46.0/announcementsservice/update_announcement_user_status.py.html>`__ to see an example of how to use update_announcement_user_status API.
        """
        resource_path = "/announcements/{announcementId}/userStatus"
        method = "PUT"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_announcement_user_status got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementId": announcement_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=status_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=status_details)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Header(object):
    """
    An HTTP header with name and value.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Header object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Header.
        :type name: str

        :param value:
            The value to assign to the value property of this Header.
        :type value: str

        """
        self.swagger_types = {
            'name': 'str',
            'value': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'value': 'value'
        }

        self._name = None
        self._value = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Header.
        The name of the header.


        :return: The name of this Header.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Header.
        The name of the header.


        :param name: The name of this Header.
        :type: str
        """
        self._name = name

    @property
    def value(self):
        """
        **[Required]** Gets the value of this Header.
        The value of the header.


        :return: The value of this Header.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Header.
        The value of the header.


        :param value: The value of this Header.
        :type: str
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpsertLogAnalyticsAssociation(object):
    """
    UpsertLogAnalyticsAssociation
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpsertLogAnalyticsAssociation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param agent_id:
            The value to assign to the agent_id property of this UpsertLogAnalyticsAssociation.
        :type agent_id: str

        :param source_name:
            The value to assign to the source_name property of this UpsertLogAnalyticsAssociation.
        :type source_name: str

        :param source_type_name:
            The value to assign to the source_type_name property of this UpsertLogAnalyticsAssociation.
        :type source_type_name: str

        :param entity_id:
            The value to assign to the entity_id property of this UpsertLogAnalyticsAssociation.
        :type entity_id: str

        :param entity_name:
            The value to assign to the entity_name property of this UpsertLogAnalyticsAssociation.
        :type entity_name: str

        :param entity_type_name:
            The value to assign to the entity_type_name property of this UpsertLogAnalyticsAssociation.
        :type entity_type_name: str

        :param host:
            The value to assign to the host property of this UpsertLogAnalyticsAssociation.
        :type host: str

        :param log_group_id:
            The value to assign to the log_group_id property of this UpsertLogAnalyticsAssociation.
        :type log_group_id: str

        """
        self.swagger_types = {
            'agent_id': 'str',
            'source_name': 'str',
            'source_type_name': 'str',
            'entity_id': 'str',
            'entity_name': 'str',
            'entity_type_name': 'str',
            'host': 'str',
            'log_group_id': 'str'
        }

        self.attribute_map = {
            'agent_id': 'agentId',
            'source_name': 'sourceName',
            'source_type_name': 'sourceTypeName',
            'entity_id': 'entityId',
            'entity_name': 'entityName',
            'entity_type_name': 'entityTypeName',
            'host': 'host',
            'log_group_id': 'logGroupId'
        }

        self._agent_id = None
        self._source_name = None
        self._source_type_name = None
        self._entity_id = None
        self._entity_name = None
        self._entity_type_name = None
        self._host = None
        self._log_group_id = None

    @property
    def agent_id(self):
        """
        Gets the agent_id of this UpsertLogAnalyticsAssociation.
        The agent unique identifier.


        :return: The agent_id of this UpsertLogAnalyticsAssociation.
        :rtype: str
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """
        Sets the agent_id of this UpsertLogAnalyticsAssociation.
        The agent unique identifier.


        :param agent_id: The agent_id of this UpsertLogAnalyticsAssociation.
        :type: str
        """
        self._agent_id = agent_id

    @property
    def source_name(self):
        """
        Gets the source_name of this UpsertLogAnalyticsAssociation.
        The source name.


        :return: The source_name of this UpsertLogAnalyticsAssociation.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this UpsertLogAnalyticsAssociation.
        The source name.


        :param source_name: The source_name of this UpsertLogAnalyticsAssociation.
        :type: str
        """
        self._source_name = source_name

    @property
    def source_type_name(self):
        """
        Gets the source_type_name of this UpsertLogAnalyticsAssociation.
        The source type internal name.


        :return: The source_type_name of this UpsertLogAnalyticsAssociation.
        :rtype: str
        """
        return self._source_type_name

    @source_type_name.setter
    def source_type_name(self, source_type_name):
        """
        Sets the source_type_name of this UpsertLogAnalyticsAssociation.
        The source type internal name.


        :param source_type_name: The source_type_name of this UpsertLogAnalyticsAssociation.
        :type: str
        """
        self._source_type_name = source_type_name

    @property
    def entity_id(self):
        """
        Gets the entity_id of this UpsertLogAnalyticsAssociation.
        The entity unique identifier.


        :return: The entity_id of this UpsertLogAnalyticsAssociation.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this UpsertLogAnalyticsAssociation.
        The entity unique identifier.


        :param entity_id: The entity_id of this UpsertLogAnalyticsAssociation.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def entity_name(self):
        """
        Gets the entity_name of this UpsertLogAnalyticsAssociation.
        The entity name.


        :return: The entity_name of this UpsertLogAnalyticsAssociation.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this UpsertLogAnalyticsAssociation.
        The entity name.


        :param entity_name: The entity_name of this UpsertLogAnalyticsAssociation.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def entity_type_name(self):
        """
        Gets the entity_type_name of this UpsertLogAnalyticsAssociation.
        The entity type internal name.


        :return: The entity_type_name of this UpsertLogAnalyticsAssociation.
        :rtype: str
        """
        return self._entity_type_name

    @entity_type_name.setter
    def entity_type_name(self, entity_type_name):
        """
        Sets the entity_type_name of this UpsertLogAnalyticsAssociation.
        The entity type internal name.


        :param entity_type_name: The entity_type_name of this UpsertLogAnalyticsAssociation.
        :type: str
        """
        self._entity_type_name = entity_type_name

    @property
    def host(self):
        """
        Gets the host of this UpsertLogAnalyticsAssociation.
        The host name.


        :return: The host of this UpsertLogAnalyticsAssociation.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this UpsertLogAnalyticsAssociation.
        The host name.


        :param host: The host of this UpsertLogAnalyticsAssociation.
        :type: str
        """
        self._host = host

    @property
    def log_group_id(self):
        """
        Gets the log_group_id of this UpsertLogAnalyticsAssociation.
        The log group unique identifier.


        :return: The log_group_id of this UpsertLogAnalyticsAssociation.
        :rtype: str
        """
        return self._log_group_id

    @log_group_id.setter
    def log_group_id(self, log_group_id):
        """
        Sets the log_group_id of this UpsertLogAnalyticsAssociation.
        The log group unique identifier.


        :param log_group_id: The log_group_id of this UpsertLogAnalyticsAssociation.
        :type: str
        """
        self._log_group_id = log_group_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EfdRegexResult(object):
    """
    EfdRegexResult
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EfdRegexResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param base_field_name:
            The value to assign to the base_field_name property of this EfdRegexResult.
        :type base_field_name: str

        :param id:
            The value to assign to the id property of this EfdRegexResult.
        :type id: int

        :param match_result:
            The value to assign to the match_result property of this EfdRegexResult.
        :type match_result: oci.log_analytics.models.RegexMatchResult

        :param parsed_field_count:
            The value to assign to the parsed_field_count property of this EfdRegexResult.
        :type parsed_field_count: int

        :param parsed_fields:
            The value to assign to the parsed_fields property of this EfdRegexResult.
        :type parsed_fields: dict(str, str)

        :param regex:
            The value to assign to the regex property of this EfdRegexResult.
        :type regex: str

        :param status:
            The value to assign to the status property of this EfdRegexResult.
        :type status: str

        :param status_description:
            The value to assign to the status_description property of this EfdRegexResult.
        :type status_description: str

        :param is_valid_regex_syntax:
            The value to assign to the is_valid_regex_syntax property of this EfdRegexResult.
        :type is_valid_regex_syntax: bool

        :param violations:
            The value to assign to the violations property of this EfdRegexResult.
        :type violations: list[oci.log_analytics.models.Violation]

        """
        self.swagger_types = {
            'base_field_name': 'str',
            'id': 'int',
            'match_result': 'RegexMatchResult',
            'parsed_field_count': 'int',
            'parsed_fields': 'dict(str, str)',
            'regex': 'str',
            'status': 'str',
            'status_description': 'str',
            'is_valid_regex_syntax': 'bool',
            'violations': 'list[Violation]'
        }

        self.attribute_map = {
            'base_field_name': 'baseFieldName',
            'id': 'id',
            'match_result': 'matchResult',
            'parsed_field_count': 'parsedFieldCount',
            'parsed_fields': 'parsedFields',
            'regex': 'regex',
            'status': 'status',
            'status_description': 'statusDescription',
            'is_valid_regex_syntax': 'isValidRegexSyntax',
            'violations': 'violations'
        }

        self._base_field_name = None
        self._id = None
        self._match_result = None
        self._parsed_field_count = None
        self._parsed_fields = None
        self._regex = None
        self._status = None
        self._status_description = None
        self._is_valid_regex_syntax = None
        self._violations = None

    @property
    def base_field_name(self):
        """
        Gets the base_field_name of this EfdRegexResult.
        The base field name.


        :return: The base_field_name of this EfdRegexResult.
        :rtype: str
        """
        return self._base_field_name

    @base_field_name.setter
    def base_field_name(self, base_field_name):
        """
        Sets the base_field_name of this EfdRegexResult.
        The base field name.


        :param base_field_name: The base_field_name of this EfdRegexResult.
        :type: str
        """
        self._base_field_name = base_field_name

    @property
    def id(self):
        """
        Gets the id of this EfdRegexResult.
        the unique identifier.


        :return: The id of this EfdRegexResult.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EfdRegexResult.
        the unique identifier.


        :param id: The id of this EfdRegexResult.
        :type: int
        """
        self._id = id

    @property
    def match_result(self):
        """
        Gets the match_result of this EfdRegexResult.

        :return: The match_result of this EfdRegexResult.
        :rtype: oci.log_analytics.models.RegexMatchResult
        """
        return self._match_result

    @match_result.setter
    def match_result(self, match_result):
        """
        Sets the match_result of this EfdRegexResult.

        :param match_result: The match_result of this EfdRegexResult.
        :type: oci.log_analytics.models.RegexMatchResult
        """
        self._match_result = match_result

    @property
    def parsed_field_count(self):
        """
        Gets the parsed_field_count of this EfdRegexResult.
        The parsed field count.


        :return: The parsed_field_count of this EfdRegexResult.
        :rtype: int
        """
        return self._parsed_field_count

    @parsed_field_count.setter
    def parsed_field_count(self, parsed_field_count):
        """
        Sets the parsed_field_count of this EfdRegexResult.
        The parsed field count.


        :param parsed_field_count: The parsed_field_count of this EfdRegexResult.
        :type: int
        """
        self._parsed_field_count = parsed_field_count

    @property
    def parsed_fields(self):
        """
        Gets the parsed_fields of this EfdRegexResult.
        The parsed fields.


        :return: The parsed_fields of this EfdRegexResult.
        :rtype: dict(str, str)
        """
        return self._parsed_fields

    @parsed_fields.setter
    def parsed_fields(self, parsed_fields):
        """
        Sets the parsed_fields of this EfdRegexResult.
        The parsed fields.


        :param parsed_fields: The parsed_fields of this EfdRegexResult.
        :type: dict(str, str)
        """
        self._parsed_fields = parsed_fields

    @property
    def regex(self):
        """
        Gets the regex of this EfdRegexResult.
        The regular expression.


        :return: The regex of this EfdRegexResult.
        :rtype: str
        """
        return self._regex

    @regex.setter
    def regex(self, regex):
        """
        Sets the regex of this EfdRegexResult.
        The regular expression.


        :param regex: The regex of this EfdRegexResult.
        :type: str
        """
        self._regex = regex

    @property
    def status(self):
        """
        Gets the status of this EfdRegexResult.
        The status.


        :return: The status of this EfdRegexResult.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this EfdRegexResult.
        The status.


        :param status: The status of this EfdRegexResult.
        :type: str
        """
        self._status = status

    @property
    def status_description(self):
        """
        Gets the status_description of this EfdRegexResult.
        The Status description.


        :return: The status_description of this EfdRegexResult.
        :rtype: str
        """
        return self._status_description

    @status_description.setter
    def status_description(self, status_description):
        """
        Sets the status_description of this EfdRegexResult.
        The Status description.


        :param status_description: The status_description of this EfdRegexResult.
        :type: str
        """
        self._status_description = status_description

    @property
    def is_valid_regex_syntax(self):
        """
        Gets the is_valid_regex_syntax of this EfdRegexResult.
        A flag indicating whether or not the regular expression is valid.


        :return: The is_valid_regex_syntax of this EfdRegexResult.
        :rtype: bool
        """
        return self._is_valid_regex_syntax

    @is_valid_regex_syntax.setter
    def is_valid_regex_syntax(self, is_valid_regex_syntax):
        """
        Sets the is_valid_regex_syntax of this EfdRegexResult.
        A flag indicating whether or not the regular expression is valid.


        :param is_valid_regex_syntax: The is_valid_regex_syntax of this EfdRegexResult.
        :type: bool
        """
        self._is_valid_regex_syntax = is_valid_regex_syntax

    @property
    def violations(self):
        """
        Gets the violations of this EfdRegexResult.
        The list of violations (if any).


        :return: The violations of this EfdRegexResult.
        :rtype: list[oci.log_analytics.models.Violation]
        """
        return self._violations

    @violations.setter
    def violations(self, violations):
        """
        Sets the violations of this EfdRegexResult.
        The list of violations (if any).


        :param violations: The violations of this EfdRegexResult.
        :type: list[oci.log_analytics.models.Violation]
        """
        self._violations = violations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .resolver_endpoint_summary import ResolverEndpointSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResolverVnicEndpointSummary(ResolverEndpointSummary):
    """
    An OCI DNS resolver VNIC endpoint.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResolverVnicEndpointSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.dns.models.ResolverVnicEndpointSummary.endpoint_type` attribute
        of this class is ``VNIC`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ResolverVnicEndpointSummary.
        :type name: str

        :param endpoint_type:
            The value to assign to the endpoint_type property of this ResolverVnicEndpointSummary.
            Allowed values for this property are: "VNIC"
        :type endpoint_type: str

        :param forwarding_address:
            The value to assign to the forwarding_address property of this ResolverVnicEndpointSummary.
        :type forwarding_address: str

        :param is_forwarding:
            The value to assign to the is_forwarding property of this ResolverVnicEndpointSummary.
        :type is_forwarding: bool

        :param is_listening:
            The value to assign to the is_listening property of this ResolverVnicEndpointSummary.
        :type is_listening: bool

        :param listening_address:
            The value to assign to the listening_address property of this ResolverVnicEndpointSummary.
        :type listening_address: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ResolverVnicEndpointSummary.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this ResolverVnicEndpointSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ResolverVnicEndpointSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ResolverVnicEndpointSummary.
            Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", "UPDATING"
        :type lifecycle_state: str

        :param _self:
            The value to assign to the _self property of this ResolverVnicEndpointSummary.
        :type _self: str

        :param subnet_id:
            The value to assign to the subnet_id property of this ResolverVnicEndpointSummary.
        :type subnet_id: str

        """
        self.swagger_types = {
            'name': 'str',
            'endpoint_type': 'str',
            'forwarding_address': 'str',
            'is_forwarding': 'bool',
            'is_listening': 'bool',
            'listening_address': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            '_self': 'str',
            'subnet_id': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'endpoint_type': 'endpointType',
            'forwarding_address': 'forwardingAddress',
            'is_forwarding': 'isForwarding',
            'is_listening': 'isListening',
            'listening_address': 'listeningAddress',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            '_self': 'self',
            'subnet_id': 'subnetId'
        }

        self._name = None
        self._endpoint_type = None
        self._forwarding_address = None
        self._is_forwarding = None
        self._is_listening = None
        self._listening_address = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self.__self = None
        self._subnet_id = None
        self._endpoint_type = 'VNIC'

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this ResolverVnicEndpointSummary.
        The OCID of a subnet. Must be part of the VCN that the resolver is attached to.


        :return: The subnet_id of this ResolverVnicEndpointSummary.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this ResolverVnicEndpointSummary.
        The OCID of a subnet. Must be part of the VCN that the resolver is attached to.


        :param subnet_id: The subnet_id of this ResolverVnicEndpointSummary.
        :type: str
        """
        self._subnet_id = subnet_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .rule_condition import RuleCondition
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SourceVcnIdCondition(RuleCondition):
    """
    An access control rule condition that requires a match on the specified source VCN OCID.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SourceVcnIdCondition object with values from keyword arguments. The default value of the :py:attr:`~oci.load_balancer.models.SourceVcnIdCondition.attribute_name` attribute
        of this class is ``SOURCE_VCN_ID`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param attribute_name:
            The value to assign to the attribute_name property of this SourceVcnIdCondition.
            Allowed values for this property are: "SOURCE_IP_ADDRESS", "SOURCE_VCN_ID", "SOURCE_VCN_IP_ADDRESS", "PATH"
        :type attribute_name: str

        :param attribute_value:
            The value to assign to the attribute_value property of this SourceVcnIdCondition.
        :type attribute_value: str

        """
        self.swagger_types = {
            'attribute_name': 'str',
            'attribute_value': 'str'
        }

        self.attribute_map = {
            'attribute_name': 'attributeName',
            'attribute_value': 'attributeValue'
        }

        self._attribute_name = None
        self._attribute_value = None
        self._attribute_name = 'SOURCE_VCN_ID'

    @property
    def attribute_value(self):
        """
        **[Required]** Gets the attribute_value of this SourceVcnIdCondition.
        The `OCID`__ of the originating VCN that an incoming packet
        must match.

        You can use this condition in conjunction with `SourceVcnIpAddressCondition`.

        **NOTE:** If you define this condition for a rule without a `SourceVcnIpAddressCondition`, this condition
        matches all incoming traffic in the specified VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The attribute_value of this SourceVcnIdCondition.
        :rtype: str
        """
        return self._attribute_value

    @attribute_value.setter
    def attribute_value(self, attribute_value):
        """
        Sets the attribute_value of this SourceVcnIdCondition.
        The `OCID`__ of the originating VCN that an incoming packet
        must match.

        You can use this condition in conjunction with `SourceVcnIpAddressCondition`.

        **NOTE:** If you define this condition for a rule without a `SourceVcnIpAddressCondition`, this condition
        matches all incoming traffic in the specified VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param attribute_value: The attribute_value of this SourceVcnIdCondition.
        :type: str
        """
        self._attribute_value = attribute_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateIPSecTunnelBgpSessionDetails(object):
    """
    UpdateIPSecTunnelBgpSessionDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateIPSecTunnelBgpSessionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param oracle_interface_ip:
            The value to assign to the oracle_interface_ip property of this UpdateIPSecTunnelBgpSessionDetails.
        :type oracle_interface_ip: str

        :param customer_interface_ip:
            The value to assign to the customer_interface_ip property of this UpdateIPSecTunnelBgpSessionDetails.
        :type customer_interface_ip: str

        :param oracle_interface_ipv6:
            The value to assign to the oracle_interface_ipv6 property of this UpdateIPSecTunnelBgpSessionDetails.
        :type oracle_interface_ipv6: str

        :param customer_interface_ipv6:
            The value to assign to the customer_interface_ipv6 property of this UpdateIPSecTunnelBgpSessionDetails.
        :type customer_interface_ipv6: str

        :param customer_bgp_asn:
            The value to assign to the customer_bgp_asn property of this UpdateIPSecTunnelBgpSessionDetails.
        :type customer_bgp_asn: str

        """
        self.swagger_types = {
            'oracle_interface_ip': 'str',
            'customer_interface_ip': 'str',
            'oracle_interface_ipv6': 'str',
            'customer_interface_ipv6': 'str',
            'customer_bgp_asn': 'str'
        }

        self.attribute_map = {
            'oracle_interface_ip': 'oracleInterfaceIp',
            'customer_interface_ip': 'customerInterfaceIp',
            'oracle_interface_ipv6': 'oracleInterfaceIpv6',
            'customer_interface_ipv6': 'customerInterfaceIpv6',
            'customer_bgp_asn': 'customerBgpAsn'
        }

        self._oracle_interface_ip = None
        self._customer_interface_ip = None
        self._oracle_interface_ipv6 = None
        self._customer_interface_ipv6 = None
        self._customer_bgp_asn = None

    @property
    def oracle_interface_ip(self):
        """
        Gets the oracle_interface_ip of this UpdateIPSecTunnelBgpSessionDetails.
        The IP address for the Oracle end of the inside tunnel interface.

        If the tunnel's `routing` attribute is set to `BGP`
        (see :func:`update_ip_sec_connection_tunnel_details`), this IP address
        is used for the tunnel's BGP session.

        If `routing` is instead set to `STATIC`, you can set this IP address to troubleshoot or
        monitor the tunnel.

        The value must be a /30 or /31.

        If you are switching the tunnel from using BGP dynamic routing to static routing and want
        to remove the value for `oracleInterfaceIp`, you can set the value to an empty string.

        Example: `10.0.0.4/31`


        :return: The oracle_interface_ip of this UpdateIPSecTunnelBgpSessionDetails.
        :rtype: str
        """
        return self._oracle_interface_ip

    @oracle_interface_ip.setter
    def oracle_interface_ip(self, oracle_interface_ip):
        """
        Sets the oracle_interface_ip of this UpdateIPSecTunnelBgpSessionDetails.
        The IP address for the Oracle end of the inside tunnel interface.

        If the tunnel's `routing` attribute is set to `BGP`
        (see :func:`update_ip_sec_connection_tunnel_details`), this IP address
        is used for the tunnel's BGP session.

        If `routing` is instead set to `STATIC`, you can set this IP address to troubleshoot or
        monitor the tunnel.

        The value must be a /30 or /31.

        If you are switching the tunnel from using BGP dynamic routing to static routing and want
        to remove the value for `oracleInterfaceIp`, you can set the value to an empty string.

        Example: `10.0.0.4/31`


        :param oracle_interface_ip: The oracle_interface_ip of this UpdateIPSecTunnelBgpSessionDetails.
        :type: str
        """
        self._oracle_interface_ip = oracle_interface_ip

    @property
    def customer_interface_ip(self):
        """
        Gets the customer_interface_ip of this UpdateIPSecTunnelBgpSessionDetails.
        The IP address for the CPE end of the inside tunnel interface.

        If the tunnel's `routing` attribute is set to `BGP`
        (see :func:`update_ip_sec_connection_tunnel_details`), this IP address
        is used for the tunnel's BGP session.

        If `routing` is instead set to `STATIC`, you can set this IP address to troubleshoot or
        monitor the tunnel.

        The value must be a /30 or /31.

        If you are switching the tunnel from using BGP dynamic routing to static routing and want
        to remove the value for `customerInterfaceIp`, you can set the value to an empty string.

        Example: `10.0.0.5/31`


        :return: The customer_interface_ip of this UpdateIPSecTunnelBgpSessionDetails.
        :rtype: str
        """
        return self._customer_interface_ip

    @customer_interface_ip.setter
    def customer_interface_ip(self, customer_interface_ip):
        """
        Sets the customer_interface_ip of this UpdateIPSecTunnelBgpSessionDetails.
        The IP address for the CPE end of the inside tunnel interface.

        If the tunnel's `routing` attribute is set to `BGP`
        (see :func:`update_ip_sec_connection_tunnel_details`), this IP address
        is used for the tunnel's BGP session.

        If `routing` is instead set to `STATIC`, you can set this IP address to troubleshoot or
        monitor the tunnel.

        The value must be a /30 or /31.

        If you are switching the tunnel from using BGP dynamic routing to static routing and want
        to remove the value for `customerInterfaceIp`, you can set the value to an empty string.

        Example: `10.0.0.5/31`


        :param customer_interface_ip: The customer_interface_ip of this UpdateIPSecTunnelBgpSessionDetails.
        :type: str
        """
        self._customer_interface_ip = customer_interface_ip

    @property
    def oracle_interface_ipv6(self):
        """
        Gets the oracle_interface_ipv6 of this UpdateIPSecTunnelBgpSessionDetails.
        The IPv6 address for the Oracle end of the inside tunnel interface. This IP address is optional.

        If the tunnel's `routing` attribute is set to `BGP`
        (see :class:`IPSecConnectionTunnel`), this IP address
        is used for the tunnel's BGP session.

        If `routing` is instead set to `STATIC`, you can set this IP
        address to troubleshoot or monitor the tunnel.

        Only subnet masks from /64 up to /127 are allowed.

        Example: `2001:db8::1/64`


        :return: The oracle_interface_ipv6 of this UpdateIPSecTunnelBgpSessionDetails.
        :rtype: str
        """
        return self._oracle_interface_ipv6

    @oracle_interface_ipv6.setter
    def oracle_interface_ipv6(self, oracle_interface_ipv6):
        """
        Sets the oracle_interface_ipv6 of this UpdateIPSecTunnelBgpSessionDetails.
        The IPv6 address for the Oracle end of the inside tunnel interface. This IP address is optional.

        If the tunnel's `routing` attribute is set to `BGP`
        (see :class:`IPSecConnectionTunnel`), this IP address
        is used for the tunnel's BGP session.

        If `routing` is instead set to `STATIC`, you can set this IP
        address to troubleshoot or monitor the tunnel.

        Only subnet masks from /64 up to /127 are allowed.

        Example: `2001:db8::1/64`


        :param oracle_interface_ipv6: The oracle_interface_ipv6 of this UpdateIPSecTunnelBgpSessionDetails.
        :type: str
        """
        self._oracle_interface_ipv6 = oracle_interface_ipv6

    @property
    def customer_interface_ipv6(self):
        """
        Gets the customer_interface_ipv6 of this UpdateIPSecTunnelBgpSessionDetails.
        The IPv6 address for the CPE end of the inside tunnel interface. This IP address is optional.

        If the tunnel's `routing` attribute is set to `BGP`
        (see :class:`IPSecConnectionTunnel`), this IP address
        is used for the tunnel's BGP session.

        If `routing` is instead set to `STATIC`, you can set this IP
        address to troubleshoot or monitor the tunnel.

        Only subnet masks from /64 up to /127 are allowed.

        Example: `2001:db8::1/64`


        :return: The customer_interface_ipv6 of this UpdateIPSecTunnelBgpSessionDetails.
        :rtype: str
        """
        return self._customer_interface_ipv6

    @customer_interface_ipv6.setter
    def customer_interface_ipv6(self, customer_interface_ipv6):
        """
        Sets the customer_interface_ipv6 of this UpdateIPSecTunnelBgpSessionDetails.
        The IPv6 address for the CPE end of the inside tunnel interface. This IP address is optional.

        If the tunnel's `routing` attribute is set to `BGP`
        (see :class:`IPSecConnectionTunnel`), this IP address
        is used for the tunnel's BGP session.

        If `routing` is instead set to `STATIC`, you can set this IP
        address to troubleshoot or monitor the tunnel.

        Only subnet masks from /64 up to /127 are allowed.

        Example: `2001:db8::1/64`


        :param customer_interface_ipv6: The customer_interface_ipv6 of this UpdateIPSecTunnelBgpSessionDetails.
        :type: str
        """
        self._customer_interface_ipv6 = customer_interface_ipv6

    @property
    def customer_bgp_asn(self):
        """
        Gets the customer_bgp_asn of this UpdateIPSecTunnelBgpSessionDetails.
        The BGP ASN of the network on the CPE end of the BGP session. Can be a 2-byte or 4-byte ASN.
        Uses \"asplain\" format.

        If you are switching the tunnel from using BGP dynamic routing to static routing, the
        `customerBgpAsn` must be null.

        Example: `12345` (2-byte) or `1587232876` (4-byte)


        :return: The customer_bgp_asn of this UpdateIPSecTunnelBgpSessionDetails.
        :rtype: str
        """
        return self._customer_bgp_asn

    @customer_bgp_asn.setter
    def customer_bgp_asn(self, customer_bgp_asn):
        """
        Sets the customer_bgp_asn of this UpdateIPSecTunnelBgpSessionDetails.
        The BGP ASN of the network on the CPE end of the BGP session. Can be a 2-byte or 4-byte ASN.
        Uses \"asplain\" format.

        If you are switching the tunnel from using BGP dynamic routing to static routing, the
        `customerBgpAsn` must be null.

        Example: `12345` (2-byte) or `1587232876` (4-byte)


        :param customer_bgp_asn: The customer_bgp_asn of this UpdateIPSecTunnelBgpSessionDetails.
        :type: str
        """
        self._customer_bgp_asn = customer_bgp_asn

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateLocalPeeringGatewayDetails(object):
    """
    CreateLocalPeeringGatewayDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateLocalPeeringGatewayDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateLocalPeeringGatewayDetails.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateLocalPeeringGatewayDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateLocalPeeringGatewayDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateLocalPeeringGatewayDetails.
        :type freeform_tags: dict(str, str)

        :param route_table_id:
            The value to assign to the route_table_id property of this CreateLocalPeeringGatewayDetails.
        :type route_table_id: str

        :param vcn_id:
            The value to assign to the vcn_id property of this CreateLocalPeeringGatewayDetails.
        :type vcn_id: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'route_table_id': 'str',
            'vcn_id': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'route_table_id': 'routeTableId',
            'vcn_id': 'vcnId'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._route_table_id = None
        self._vcn_id = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateLocalPeeringGatewayDetails.
        The OCID of the compartment containing the local peering gateway (LPG).


        :return: The compartment_id of this CreateLocalPeeringGatewayDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateLocalPeeringGatewayDetails.
        The OCID of the compartment containing the local peering gateway (LPG).


        :param compartment_id: The compartment_id of this CreateLocalPeeringGatewayDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateLocalPeeringGatewayDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateLocalPeeringGatewayDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateLocalPeeringGatewayDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateLocalPeeringGatewayDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateLocalPeeringGatewayDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :return: The display_name of this CreateLocalPeeringGatewayDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateLocalPeeringGatewayDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :param display_name: The display_name of this CreateLocalPeeringGatewayDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateLocalPeeringGatewayDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateLocalPeeringGatewayDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateLocalPeeringGatewayDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateLocalPeeringGatewayDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this CreateLocalPeeringGatewayDetails.
        The OCID of the route table the LPG will use.

        If you don't specify a route table here, the LPG is created without an associated route
        table. The Networking service does NOT automatically associate the attached VCN's default route table
        with the LPG.

        For information about why you would associate a route table with an LPG, see
        `Transit Routing: Access to Multiple VCNs in Same Region`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm


        :return: The route_table_id of this CreateLocalPeeringGatewayDetails.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this CreateLocalPeeringGatewayDetails.
        The OCID of the route table the LPG will use.

        If you don't specify a route table here, the LPG is created without an associated route
        table. The Networking service does NOT automatically associate the attached VCN's default route table
        with the LPG.

        For information about why you would associate a route table with an LPG, see
        `Transit Routing: Access to Multiple VCNs in Same Region`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm


        :param route_table_id: The route_table_id of this CreateLocalPeeringGatewayDetails.
        :type: str
        """
        self._route_table_id = route_table_id

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this CreateLocalPeeringGatewayDetails.
        The OCID of the VCN the LPG belongs to.


        :return: The vcn_id of this CreateLocalPeeringGatewayDetails.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this CreateLocalPeeringGatewayDetails.
        The OCID of the VCN the LPG belongs to.


        :param vcn_id: The vcn_id of this CreateLocalPeeringGatewayDetails.
        :type: str
        """
        self._vcn_id = vcn_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateIndexDetails(object):
    """
    Specifications for the new index.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateIndexDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreateIndexDetails.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateIndexDetails.
        :type compartment_id: str

        :param keys:
            The value to assign to the keys property of this CreateIndexDetails.
        :type keys: list[oci.nosql.models.IndexKey]

        :param is_if_not_exists:
            The value to assign to the is_if_not_exists property of this CreateIndexDetails.
        :type is_if_not_exists: bool

        """
        self.swagger_types = {
            'name': 'str',
            'compartment_id': 'str',
            'keys': 'list[IndexKey]',
            'is_if_not_exists': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'compartment_id': 'compartmentId',
            'keys': 'keys',
            'is_if_not_exists': 'isIfNotExists'
        }

        self._name = None
        self._compartment_id = None
        self._keys = None
        self._is_if_not_exists = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateIndexDetails.
        Index name.


        :return: The name of this CreateIndexDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateIndexDetails.
        Index name.


        :param name: The name of this CreateIndexDetails.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this CreateIndexDetails.
        The OCID of the table's compartment.  Required
        if the tableNameOrId path parameter is a table name.
        Optional if tableNameOrId is an OCID.  If tableNameOrId
        is an OCID, and compartmentId is supplied, the latter
        must match the identified table's compartmentId.


        :return: The compartment_id of this CreateIndexDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateIndexDetails.
        The OCID of the table's compartment.  Required
        if the tableNameOrId path parameter is a table name.
        Optional if tableNameOrId is an OCID.  If tableNameOrId
        is an OCID, and compartmentId is supplied, the latter
        must match the identified table's compartmentId.


        :param compartment_id: The compartment_id of this CreateIndexDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def keys(self):
        """
        **[Required]** Gets the keys of this CreateIndexDetails.
        A set of keys for a secondary index.


        :return: The keys of this CreateIndexDetails.
        :rtype: list[oci.nosql.models.IndexKey]
        """
        return self._keys

    @keys.setter
    def keys(self, keys):
        """
        Sets the keys of this CreateIndexDetails.
        A set of keys for a secondary index.


        :param keys: The keys of this CreateIndexDetails.
        :type: list[oci.nosql.models.IndexKey]
        """
        self._keys = keys

    @property
    def is_if_not_exists(self):
        """
        Gets the is_if_not_exists of this CreateIndexDetails.
        If true, the operation completes successfully even when the
        index exists.  Otherwise, an attempt to create an index
        that already exists will return an error.


        :return: The is_if_not_exists of this CreateIndexDetails.
        :rtype: bool
        """
        return self._is_if_not_exists

    @is_if_not_exists.setter
    def is_if_not_exists(self, is_if_not_exists):
        """
        Sets the is_if_not_exists of this CreateIndexDetails.
        If true, the operation completes successfully even when the
        index exists.  Otherwise, an attempt to create an index
        that already exists will return an error.


        :param is_if_not_exists: The is_if_not_exists of this CreateIndexDetails.
        :type: bool
        """
        self._is_if_not_exists = is_if_not_exists

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_oce_instance_compartment_details import ChangeOceInstanceCompartmentDetails
from .create_oce_instance_details import CreateOceInstanceDetails
from .identity_stripe_details import IdentityStripeDetails
from .oce_instance import OceInstance
from .oce_instance_summary import OceInstanceSummary
from .update_oce_instance_details import UpdateOceInstanceDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .workflow_monitor import WorkflowMonitor
from .workflow_step import WorkflowStep

# Maps type names to classes for oce services.
oce_type_mapping = {
    "ChangeOceInstanceCompartmentDetails": ChangeOceInstanceCompartmentDetails,
    "CreateOceInstanceDetails": CreateOceInstanceDetails,
    "IdentityStripeDetails": IdentityStripeDetails,
    "OceInstance": OceInstance,
    "OceInstanceSummary": OceInstanceSummary,
    "UpdateOceInstanceDetails": UpdateOceInstanceDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkflowMonitor": WorkflowMonitor,
    "WorkflowStep": WorkflowStep
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateOperatorControlDetails(object):
    """
    While creating the operator control, specify how operator actions are approved and the users who have the privilege of approving the operator actions associated with the Operator Control.

    You must specify which operator actions must be pre-approved. The rest of the operator actions associated with the Operator Control will require an explicit approval from the users selected either through the approver groups or individually.

    You must name your Operator Control appropriately so it reflects the resources that will be governed by the Operator Control. Neither the Operator Controls nor their assignments to resources are visible to the Oracle operators.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateOperatorControlDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operator_control_name:
            The value to assign to the operator_control_name property of this CreateOperatorControlDetails.
        :type operator_control_name: str

        :param description:
            The value to assign to the description property of this CreateOperatorControlDetails.
        :type description: str

        :param approvers_list:
            The value to assign to the approvers_list property of this CreateOperatorControlDetails.
        :type approvers_list: list[str]

        :param approver_groups_list:
            The value to assign to the approver_groups_list property of this CreateOperatorControlDetails.
        :type approver_groups_list: list[str]

        :param pre_approved_op_action_list:
            The value to assign to the pre_approved_op_action_list property of this CreateOperatorControlDetails.
        :type pre_approved_op_action_list: list[str]

        :param is_fully_pre_approved:
            The value to assign to the is_fully_pre_approved property of this CreateOperatorControlDetails.
        :type is_fully_pre_approved: bool

        :param email_id_list:
            The value to assign to the email_id_list property of this CreateOperatorControlDetails.
        :type email_id_list: list[str]

        :param system_message:
            The value to assign to the system_message property of this CreateOperatorControlDetails.
        :type system_message: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateOperatorControlDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateOperatorControlDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateOperatorControlDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'operator_control_name': 'str',
            'description': 'str',
            'approvers_list': 'list[str]',
            'approver_groups_list': 'list[str]',
            'pre_approved_op_action_list': 'list[str]',
            'is_fully_pre_approved': 'bool',
            'email_id_list': 'list[str]',
            'system_message': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'operator_control_name': 'operatorControlName',
            'description': 'description',
            'approvers_list': 'approversList',
            'approver_groups_list': 'approverGroupsList',
            'pre_approved_op_action_list': 'preApprovedOpActionList',
            'is_fully_pre_approved': 'isFullyPreApproved',
            'email_id_list': 'emailIdList',
            'system_message': 'systemMessage',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._operator_control_name = None
        self._description = None
        self._approvers_list = None
        self._approver_groups_list = None
        self._pre_approved_op_action_list = None
        self._is_fully_pre_approved = None
        self._email_id_list = None
        self._system_message = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def operator_control_name(self):
        """
        **[Required]** Gets the operator_control_name of this CreateOperatorControlDetails.
        Name of the operator control.


        :return: The operator_control_name of this CreateOperatorControlDetails.
        :rtype: str
        """
        return self._operator_control_name

    @operator_control_name.setter
    def operator_control_name(self, operator_control_name):
        """
        Sets the operator_control_name of this CreateOperatorControlDetails.
        Name of the operator control.


        :param operator_control_name: The operator_control_name of this CreateOperatorControlDetails.
        :type: str
        """
        self._operator_control_name = operator_control_name

    @property
    def description(self):
        """
        Gets the description of this CreateOperatorControlDetails.
        Description of the operator control.


        :return: The description of this CreateOperatorControlDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateOperatorControlDetails.
        Description of the operator control.


        :param description: The description of this CreateOperatorControlDetails.
        :type: str
        """
        self._description = description

    @property
    def approvers_list(self):
        """
        Gets the approvers_list of this CreateOperatorControlDetails.
        List of users who can approve an access request associated with a resource governed by this operator control.


        :return: The approvers_list of this CreateOperatorControlDetails.
        :rtype: list[str]
        """
        return self._approvers_list

    @approvers_list.setter
    def approvers_list(self, approvers_list):
        """
        Sets the approvers_list of this CreateOperatorControlDetails.
        List of users who can approve an access request associated with a resource governed by this operator control.


        :param approvers_list: The approvers_list of this CreateOperatorControlDetails.
        :type: list[str]
        """
        self._approvers_list = approvers_list

    @property
    def approver_groups_list(self):
        """
        Gets the approver_groups_list of this CreateOperatorControlDetails.
        List of user groups who can approve an access request associated with a resource governed by this operator control.


        :return: The approver_groups_list of this CreateOperatorControlDetails.
        :rtype: list[str]
        """
        return self._approver_groups_list

    @approver_groups_list.setter
    def approver_groups_list(self, approver_groups_list):
        """
        Sets the approver_groups_list of this CreateOperatorControlDetails.
        List of user groups who can approve an access request associated with a resource governed by this operator control.


        :param approver_groups_list: The approver_groups_list of this CreateOperatorControlDetails.
        :type: list[str]
        """
        self._approver_groups_list = approver_groups_list

    @property
    def pre_approved_op_action_list(self):
        """
        Gets the pre_approved_op_action_list of this CreateOperatorControlDetails.
        List of pre-approved operator actions. Access requests associated with a resource governed by this operator control will be
        auto-approved if the access request only contain operator actions in the pre-approved list.


        :return: The pre_approved_op_action_list of this CreateOperatorControlDetails.
        :rtype: list[str]
        """
        return self._pre_approved_op_action_list

    @pre_approved_op_action_list.setter
    def pre_approved_op_action_list(self, pre_approved_op_action_list):
        """
        Sets the pre_approved_op_action_list of this CreateOperatorControlDetails.
        List of pre-approved operator actions. Access requests associated with a resource governed by this operator control will be
        auto-approved if the access request only contain operator actions in the pre-approved list.


        :param pre_approved_op_action_list: The pre_approved_op_action_list of this CreateOperatorControlDetails.
        :type: list[str]
        """
        self._pre_approved_op_action_list = pre_approved_op_action_list

    @property
    def is_fully_pre_approved(self):
        """
        Gets the is_fully_pre_approved of this CreateOperatorControlDetails.
        Whether all the operator actions have been pre-approved. If yes, all access requests associated with a resource governed by this operator control
        will be auto-approved.


        :return: The is_fully_pre_approved of this CreateOperatorControlDetails.
        :rtype: bool
        """
        return self._is_fully_pre_approved

    @is_fully_pre_approved.setter
    def is_fully_pre_approved(self, is_fully_pre_approved):
        """
        Sets the is_fully_pre_approved of this CreateOperatorControlDetails.
        Whether all the operator actions have been pre-approved. If yes, all access requests associated with a resource governed by this operator control
        will be auto-approved.


        :param is_fully_pre_approved: The is_fully_pre_approved of this CreateOperatorControlDetails.
        :type: bool
        """
        self._is_fully_pre_approved = is_fully_pre_approved

    @property
    def email_id_list(self):
        """
        Gets the email_id_list of this CreateOperatorControlDetails.
        List of emailId.


        :return: The email_id_list of this CreateOperatorControlDetails.
        :rtype: list[str]
        """
        return self._email_id_list

    @email_id_list.setter
    def email_id_list(self, email_id_list):
        """
        Sets the email_id_list of this CreateOperatorControlDetails.
        List of emailId.


        :param email_id_list: The email_id_list of this CreateOperatorControlDetails.
        :type: list[str]
        """
        self._email_id_list = email_id_list

    @property
    def system_message(self):
        """
        Gets the system_message of this CreateOperatorControlDetails.
        This is the message that will be displayed to the operator users while accessing the system.


        :return: The system_message of this CreateOperatorControlDetails.
        :rtype: str
        """
        return self._system_message

    @system_message.setter
    def system_message(self, system_message):
        """
        Sets the system_message of this CreateOperatorControlDetails.
        This is the message that will be displayed to the operator users while accessing the system.


        :param system_message: The system_message of this CreateOperatorControlDetails.
        :type: str
        """
        self._system_message = system_message

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateOperatorControlDetails.
        The OCID of the compartment that contains this operator control.


        :return: The compartment_id of this CreateOperatorControlDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateOperatorControlDetails.
        The OCID of the compartment that contains this operator control.


        :param compartment_id: The compartment_id of this CreateOperatorControlDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateOperatorControlDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.


        :return: The freeform_tags of this CreateOperatorControlDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateOperatorControlDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.


        :param freeform_tags: The freeform_tags of this CreateOperatorControlDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateOperatorControlDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.


        :return: The defined_tags of this CreateOperatorControlDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateOperatorControlDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.


        :param defined_tags: The defined_tags of this CreateOperatorControlDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_format_attribute import AbstractFormatAttribute
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CsvFormatAttribute(AbstractFormatAttribute):
    """
    The CSV format attribute.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CsvFormatAttribute object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.CsvFormatAttribute.model_type` attribute
        of this class is ``CSV_FORMAT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this CsvFormatAttribute.
            Allowed values for this property are: "JSON_FORMAT", "CSV_FORMAT", "AVRO_FORMAT"
        :type model_type: str

        :param is_file_pattern:
            The value to assign to the is_file_pattern property of this CsvFormatAttribute.
        :type is_file_pattern: bool

        :param encoding:
            The value to assign to the encoding property of this CsvFormatAttribute.
        :type encoding: str

        :param escape_character:
            The value to assign to the escape_character property of this CsvFormatAttribute.
        :type escape_character: str

        :param delimiter:
            The value to assign to the delimiter property of this CsvFormatAttribute.
        :type delimiter: str

        :param quote_character:
            The value to assign to the quote_character property of this CsvFormatAttribute.
        :type quote_character: str

        :param has_header:
            The value to assign to the has_header property of this CsvFormatAttribute.
        :type has_header: bool

        :param timestamp_format:
            The value to assign to the timestamp_format property of this CsvFormatAttribute.
        :type timestamp_format: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'is_file_pattern': 'bool',
            'encoding': 'str',
            'escape_character': 'str',
            'delimiter': 'str',
            'quote_character': 'str',
            'has_header': 'bool',
            'timestamp_format': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'is_file_pattern': 'isFilePattern',
            'encoding': 'encoding',
            'escape_character': 'escapeCharacter',
            'delimiter': 'delimiter',
            'quote_character': 'quoteCharacter',
            'has_header': 'hasHeader',
            'timestamp_format': 'timestampFormat'
        }

        self._model_type = None
        self._is_file_pattern = None
        self._encoding = None
        self._escape_character = None
        self._delimiter = None
        self._quote_character = None
        self._has_header = None
        self._timestamp_format = None
        self._model_type = 'CSV_FORMAT'

    @property
    def encoding(self):
        """
        Gets the encoding of this CsvFormatAttribute.
        The encoding for the file.


        :return: The encoding of this CsvFormatAttribute.
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """
        Sets the encoding of this CsvFormatAttribute.
        The encoding for the file.


        :param encoding: The encoding of this CsvFormatAttribute.
        :type: str
        """
        self._encoding = encoding

    @property
    def escape_character(self):
        """
        Gets the escape_character of this CsvFormatAttribute.
        The escape character for the CSV format.


        :return: The escape_character of this CsvFormatAttribute.
        :rtype: str
        """
        return self._escape_character

    @escape_character.setter
    def escape_character(self, escape_character):
        """
        Sets the escape_character of this CsvFormatAttribute.
        The escape character for the CSV format.


        :param escape_character: The escape_character of this CsvFormatAttribute.
        :type: str
        """
        self._escape_character = escape_character

    @property
    def delimiter(self):
        """
        Gets the delimiter of this CsvFormatAttribute.
        The delimiter for the CSV format.


        :return: The delimiter of this CsvFormatAttribute.
        :rtype: str
        """
        return self._delimiter

    @delimiter.setter
    def delimiter(self, delimiter):
        """
        Sets the delimiter of this CsvFormatAttribute.
        The delimiter for the CSV format.


        :param delimiter: The delimiter of this CsvFormatAttribute.
        :type: str
        """
        self._delimiter = delimiter

    @property
    def quote_character(self):
        """
        Gets the quote_character of this CsvFormatAttribute.
        The quote character for the CSV format.


        :return: The quote_character of this CsvFormatAttribute.
        :rtype: str
        """
        return self._quote_character

    @quote_character.setter
    def quote_character(self, quote_character):
        """
        Sets the quote_character of this CsvFormatAttribute.
        The quote character for the CSV format.


        :param quote_character: The quote_character of this CsvFormatAttribute.
        :type: str
        """
        self._quote_character = quote_character

    @property
    def has_header(self):
        """
        Gets the has_header of this CsvFormatAttribute.
        Defines whether the file has a header row.


        :return: The has_header of this CsvFormatAttribute.
        :rtype: bool
        """
        return self._has_header

    @has_header.setter
    def has_header(self, has_header):
        """
        Sets the has_header of this CsvFormatAttribute.
        Defines whether the file has a header row.


        :param has_header: The has_header of this CsvFormatAttribute.
        :type: bool
        """
        self._has_header = has_header

    @property
    def timestamp_format(self):
        """
        Gets the timestamp_format of this CsvFormatAttribute.
        Format for timestamp information.


        :return: The timestamp_format of this CsvFormatAttribute.
        :rtype: str
        """
        return self._timestamp_format

    @timestamp_format.setter
    def timestamp_format(self, timestamp_format):
        """
        Sets the timestamp_format of this CsvFormatAttribute.
        Format for timestamp information.


        :param timestamp_format: The timestamp_format of this CsvFormatAttribute.
        :type: str
        """
        self._timestamp_format = timestamp_format

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceAgentCommandContentInfo(object):
    """
    The command content.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceAgentCommandContentInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param instance_agent_command_id:
            The value to assign to the instance_agent_command_id property of this InstanceAgentCommandContentInfo.
        :type instance_agent_command_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this InstanceAgentCommandContentInfo.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this InstanceAgentCommandContentInfo.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this InstanceAgentCommandContentInfo.
        :type time_updated: datetime

        :param is_canceled:
            The value to assign to the is_canceled property of this InstanceAgentCommandContentInfo.
        :type is_canceled: bool

        :param execution_time_out_in_seconds:
            The value to assign to the execution_time_out_in_seconds property of this InstanceAgentCommandContentInfo.
        :type execution_time_out_in_seconds: int

        :param content:
            The value to assign to the content property of this InstanceAgentCommandContentInfo.
        :type content: oci.compute_instance_agent.models.InstanceAgentCommandContent

        """
        self.swagger_types = {
            'instance_agent_command_id': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'is_canceled': 'bool',
            'execution_time_out_in_seconds': 'int',
            'content': 'InstanceAgentCommandContent'
        }

        self.attribute_map = {
            'instance_agent_command_id': 'instanceAgentCommandId',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'is_canceled': 'isCanceled',
            'execution_time_out_in_seconds': 'executionTimeOutInSeconds',
            'content': 'content'
        }

        self._instance_agent_command_id = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._is_canceled = None
        self._execution_time_out_in_seconds = None
        self._content = None

    @property
    def instance_agent_command_id(self):
        """
        **[Required]** Gets the instance_agent_command_id of this InstanceAgentCommandContentInfo.
        The command ocid


        :return: The instance_agent_command_id of this InstanceAgentCommandContentInfo.
        :rtype: str
        """
        return self._instance_agent_command_id

    @instance_agent_command_id.setter
    def instance_agent_command_id(self, instance_agent_command_id):
        """
        Sets the instance_agent_command_id of this InstanceAgentCommandContentInfo.
        The command ocid


        :param instance_agent_command_id: The instance_agent_command_id of this InstanceAgentCommandContentInfo.
        :type: str
        """
        self._instance_agent_command_id = instance_agent_command_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this InstanceAgentCommandContentInfo.
        The OCID of the compartment the command is created in.


        :return: The compartment_id of this InstanceAgentCommandContentInfo.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this InstanceAgentCommandContentInfo.
        The OCID of the compartment the command is created in.


        :param compartment_id: The compartment_id of this InstanceAgentCommandContentInfo.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_created(self):
        """
        Gets the time_created of this InstanceAgentCommandContentInfo.
        created at time of command.


        :return: The time_created of this InstanceAgentCommandContentInfo.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this InstanceAgentCommandContentInfo.
        created at time of command.


        :param time_created: The time_created of this InstanceAgentCommandContentInfo.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this InstanceAgentCommandContentInfo.
        updated time of command.


        :return: The time_updated of this InstanceAgentCommandContentInfo.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this InstanceAgentCommandContentInfo.
        updated time of command.


        :param time_updated: The time_updated of this InstanceAgentCommandContentInfo.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def is_canceled(self):
        """
        Gets the is_canceled of this InstanceAgentCommandContentInfo.
        Whether the command has been canceled.


        :return: The is_canceled of this InstanceAgentCommandContentInfo.
        :rtype: bool
        """
        return self._is_canceled

    @is_canceled.setter
    def is_canceled(self, is_canceled):
        """
        Sets the is_canceled of this InstanceAgentCommandContentInfo.
        Whether the command has been canceled.


        :param is_canceled: The is_canceled of this InstanceAgentCommandContentInfo.
        :type: bool
        """
        self._is_canceled = is_canceled

    @property
    def execution_time_out_in_seconds(self):
        """
        Gets the execution_time_out_in_seconds of this InstanceAgentCommandContentInfo.
        The last command time.


        :return: The execution_time_out_in_seconds of this InstanceAgentCommandContentInfo.
        :rtype: int
        """
        return self._execution_time_out_in_seconds

    @execution_time_out_in_seconds.setter
    def execution_time_out_in_seconds(self, execution_time_out_in_seconds):
        """
        Sets the execution_time_out_in_seconds of this InstanceAgentCommandContentInfo.
        The last command time.


        :param execution_time_out_in_seconds: The execution_time_out_in_seconds of this InstanceAgentCommandContentInfo.
        :type: int
        """
        self._execution_time_out_in_seconds = execution_time_out_in_seconds

    @property
    def content(self):
        """
        **[Required]** Gets the content of this InstanceAgentCommandContentInfo.

        :return: The content of this InstanceAgentCommandContentInfo.
        :rtype: oci.compute_instance_agent.models.InstanceAgentCommandContent
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this InstanceAgentCommandContentInfo.

        :param content: The content of this InstanceAgentCommandContentInfo.
        :type: oci.compute_instance_agent.models.InstanceAgentCommandContent
        """
        self._content = content

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BlockVolumeReplica(object):
    """
    An asynchronous replica of a block volume that can then be used to create
    a new block volume or recover a block volume. For more information, see `Overview
    of Cross-Region Volume Replication`__
    To use any of the API operations, you must be authorized in an IAM policy.
    If you're not authorized, talk to an administrator. If you're an administrator
    who needs to write policies to give users access, see `Getting Started with
    Policies`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you
    supply string values using the API.

    __ https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumereplication.htm
    __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a BlockVolumeReplica.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a BlockVolumeReplica.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a BlockVolumeReplica.
    #: This constant has a value of "ACTIVATING"
    LIFECYCLE_STATE_ACTIVATING = "ACTIVATING"

    #: A constant which can be used with the lifecycle_state property of a BlockVolumeReplica.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a BlockVolumeReplica.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a BlockVolumeReplica.
    #: This constant has a value of "FAULTY"
    LIFECYCLE_STATE_FAULTY = "FAULTY"

    def __init__(self, **kwargs):
        """
        Initializes a new BlockVolumeReplica object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this BlockVolumeReplica.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this BlockVolumeReplica.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this BlockVolumeReplica.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this BlockVolumeReplica.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this BlockVolumeReplica.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this BlockVolumeReplica.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this BlockVolumeReplica.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "ACTIVATING", "TERMINATING", "TERMINATED", "FAULTY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param size_in_gbs:
            The value to assign to the size_in_gbs property of this BlockVolumeReplica.
        :type size_in_gbs: int

        :param time_created:
            The value to assign to the time_created property of this BlockVolumeReplica.
        :type time_created: datetime

        :param time_last_synced:
            The value to assign to the time_last_synced property of this BlockVolumeReplica.
        :type time_last_synced: datetime

        :param block_volume_id:
            The value to assign to the block_volume_id property of this BlockVolumeReplica.
        :type block_volume_id: str

        :param total_data_transferred_in_gbs:
            The value to assign to the total_data_transferred_in_gbs property of this BlockVolumeReplica.
        :type total_data_transferred_in_gbs: int

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'lifecycle_state': 'str',
            'size_in_gbs': 'int',
            'time_created': 'datetime',
            'time_last_synced': 'datetime',
            'block_volume_id': 'str',
            'total_data_transferred_in_gbs': 'int'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'size_in_gbs': 'sizeInGBs',
            'time_created': 'timeCreated',
            'time_last_synced': 'timeLastSynced',
            'block_volume_id': 'blockVolumeId',
            'total_data_transferred_in_gbs': 'totalDataTransferredInGBs'
        }

        self._availability_domain = None
        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._lifecycle_state = None
        self._size_in_gbs = None
        self._time_created = None
        self._time_last_synced = None
        self._block_volume_id = None
        self._total_data_transferred_in_gbs = None

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this BlockVolumeReplica.
        The availability domain of the block volume replica.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this BlockVolumeReplica.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this BlockVolumeReplica.
        The availability domain of the block volume replica.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this BlockVolumeReplica.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this BlockVolumeReplica.
        The OCID of the compartment that contains the block volume replica.


        :return: The compartment_id of this BlockVolumeReplica.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this BlockVolumeReplica.
        The OCID of the compartment that contains the block volume replica.


        :param compartment_id: The compartment_id of this BlockVolumeReplica.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this BlockVolumeReplica.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this BlockVolumeReplica.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this BlockVolumeReplica.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this BlockVolumeReplica.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this BlockVolumeReplica.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this BlockVolumeReplica.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this BlockVolumeReplica.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this BlockVolumeReplica.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this BlockVolumeReplica.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this BlockVolumeReplica.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this BlockVolumeReplica.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this BlockVolumeReplica.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this BlockVolumeReplica.
        The block volume replica's Oracle ID (OCID).


        :return: The id of this BlockVolumeReplica.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BlockVolumeReplica.
        The block volume replica's Oracle ID (OCID).


        :param id: The id of this BlockVolumeReplica.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this BlockVolumeReplica.
        The current state of a block volume replica.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "ACTIVATING", "TERMINATING", "TERMINATED", "FAULTY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this BlockVolumeReplica.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this BlockVolumeReplica.
        The current state of a block volume replica.


        :param lifecycle_state: The lifecycle_state of this BlockVolumeReplica.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "ACTIVATING", "TERMINATING", "TERMINATED", "FAULTY"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def size_in_gbs(self):
        """
        **[Required]** Gets the size_in_gbs of this BlockVolumeReplica.
        The size of the source block volume, in GBs.


        :return: The size_in_gbs of this BlockVolumeReplica.
        :rtype: int
        """
        return self._size_in_gbs

    @size_in_gbs.setter
    def size_in_gbs(self, size_in_gbs):
        """
        Sets the size_in_gbs of this BlockVolumeReplica.
        The size of the source block volume, in GBs.


        :param size_in_gbs: The size_in_gbs of this BlockVolumeReplica.
        :type: int
        """
        self._size_in_gbs = size_in_gbs

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this BlockVolumeReplica.
        The date and time the block volume replica was created. Format defined
        by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this BlockVolumeReplica.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this BlockVolumeReplica.
        The date and time the block volume replica was created. Format defined
        by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this BlockVolumeReplica.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_last_synced(self):
        """
        **[Required]** Gets the time_last_synced of this BlockVolumeReplica.
        The date and time the block volume replica was last synced from the source block volume.
        Format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_last_synced of this BlockVolumeReplica.
        :rtype: datetime
        """
        return self._time_last_synced

    @time_last_synced.setter
    def time_last_synced(self, time_last_synced):
        """
        Sets the time_last_synced of this BlockVolumeReplica.
        The date and time the block volume replica was last synced from the source block volume.
        Format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_last_synced: The time_last_synced of this BlockVolumeReplica.
        :type: datetime
        """
        self._time_last_synced = time_last_synced

    @property
    def block_volume_id(self):
        """
        **[Required]** Gets the block_volume_id of this BlockVolumeReplica.
        The OCID of the source block volume.


        :return: The block_volume_id of this BlockVolumeReplica.
        :rtype: str
        """
        return self._block_volume_id

    @block_volume_id.setter
    def block_volume_id(self, block_volume_id):
        """
        Sets the block_volume_id of this BlockVolumeReplica.
        The OCID of the source block volume.


        :param block_volume_id: The block_volume_id of this BlockVolumeReplica.
        :type: str
        """
        self._block_volume_id = block_volume_id

    @property
    def total_data_transferred_in_gbs(self):
        """
        Gets the total_data_transferred_in_gbs of this BlockVolumeReplica.
        The total size of the data transferred from the source block volume to the block volume replica, in GBs.


        :return: The total_data_transferred_in_gbs of this BlockVolumeReplica.
        :rtype: int
        """
        return self._total_data_transferred_in_gbs

    @total_data_transferred_in_gbs.setter
    def total_data_transferred_in_gbs(self, total_data_transferred_in_gbs):
        """
        Sets the total_data_transferred_in_gbs of this BlockVolumeReplica.
        The total size of the data transferred from the source block volume to the block volume replica, in GBs.


        :param total_data_transferred_in_gbs: The total_data_transferred_in_gbs of this BlockVolumeReplica.
        :type: int
        """
        self._total_data_transferred_in_gbs = total_data_transferred_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_upgrade_source_base import DatabaseUpgradeSourceBase
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseUpgradeWithDbVersionDetails(DatabaseUpgradeSourceBase):
    """
    Details of the Oracle Database software version number for upgrading a database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseUpgradeWithDbVersionDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.DatabaseUpgradeWithDbVersionDetails.source` attribute
        of this class is ``DB_VERSION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this DatabaseUpgradeWithDbVersionDetails.
            Allowed values for this property are: "DB_HOME", "DB_VERSION", "DB_SOFTWARE_IMAGE"
        :type source: str

        :param options:
            The value to assign to the options property of this DatabaseUpgradeWithDbVersionDetails.
        :type options: str

        :param db_version:
            The value to assign to the db_version property of this DatabaseUpgradeWithDbVersionDetails.
        :type db_version: str

        """
        self.swagger_types = {
            'source': 'str',
            'options': 'str',
            'db_version': 'str'
        }

        self.attribute_map = {
            'source': 'source',
            'options': 'options',
            'db_version': 'dbVersion'
        }

        self._source = None
        self._options = None
        self._db_version = None
        self._source = 'DB_VERSION'

    @property
    def db_version(self):
        """
        **[Required]** Gets the db_version of this DatabaseUpgradeWithDbVersionDetails.
        A valid Oracle Database version. To get a list of supported versions, use the :func:`list_db_versions` operation.


        :return: The db_version of this DatabaseUpgradeWithDbVersionDetails.
        :rtype: str
        """
        return self._db_version

    @db_version.setter
    def db_version(self, db_version):
        """
        Sets the db_version of this DatabaseUpgradeWithDbVersionDetails.
        A valid Oracle Database version. To get a list of supported versions, use the :func:`list_db_versions` operation.


        :param db_version: The db_version of this DatabaseUpgradeWithDbVersionDetails.
        :type: str
        """
        self._db_version = db_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
